@@ -1,10 +1,12 @@
 from .accessibility import *
 from .colgen import *
 from .dtaapi import *
+from .simulation import *
 from .utils import *
+from .zonesyn import *
 
 
-__version__ = '0.8.4'
+__version__ = '0.9.0'
 
 
 # print out the current version
