@@ -8,11 +8,11 @@ Two path engines are provided:
 """
 
 
-import ctypes
 import collections
+import ctypes
 import heapq
 import os.path
-from sys import platform
+import platform
 
 from .consts import MAX_LABEL_COST
 
@@ -25,12 +25,17 @@ __all__ = [
 ]
 
 
-if platform.startswith('win32'):
+_os = platform.system()
+if _os.startswith('Windows'):
     _dll_file = os.path.join(os.path.dirname(__file__), 'bin/path_engine.dll')
-elif platform.startswith('linux'):
+elif _os.startswith('Linux'):
     _dll_file = os.path.join(os.path.dirname(__file__), 'bin/path_engine.so')
-elif platform.startswith('darwin'):
-    _dll_file = os.path.join(os.path.dirname(__file__), 'bin/path_engine.dylib')
+elif _os.startswith('Darwin'):
+    # check CPU is Intel or Apple Silicon
+    if platform.machine().startswith('x86_64'):
+        _dll_file = os.path.join(os.path.dirname(__file__), 'bin/path_engine_x86.dylib')
+    else:
+        _dll_file = os.path.join(os.path.dirname(__file__), 'bin/path_engine_arm.dylib')
 else:
     raise Exception('Please build the shared library compatible to your OS\
                     using source files in engine_cpp!')
@@ -103,7 +108,7 @@ def _single_source_shortest_path_fifo(G, origin_node_no):
     while SEList:
         from_node = SEList.pop(0)
         status[from_node] = 0
-        for link in G.node_list[from_node].outgoing_link_list:
+        for link in G.nodes[from_node].outgoing_links:
             to_node = link.to_node_seq_no
             new_to_node_cost = (G.node_label_cost[from_node]
                                 + link.cost)
@@ -114,10 +119,10 @@ def _single_source_shortest_path_fifo(G, origin_node_no):
                 G.node_label_cost[to_node] = new_to_node_cost
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.node_predecessor[to_node] = from_node
+                G.node_preds[to_node] = from_node
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.link_predecessor[to_node] = link.link_seq_no
+                G.link_preds[to_node] = link.link_seq_no
                 if not status[to_node]:
                     SEList.append(to_node)
                     status[to_node] = 1
@@ -143,7 +148,7 @@ def _single_source_shortest_path_deque(G, origin_node_no):
     while SEList:
         from_node = SEList.popleft()
         status[from_node] = 2
-        for link in G.node_list[from_node].outgoing_link_list:
+        for link in G.nodes[from_node].outgoing_links:
             to_node = link.to_node_seq_no
             new_to_node_cost = (G.node_label_cost[from_node]
                                 + link.cost)
@@ -154,10 +159,10 @@ def _single_source_shortest_path_deque(G, origin_node_no):
                 G.node_label_cost[to_node] = new_to_node_cost
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.node_predecessor[to_node] = from_node
+                G.node_preds[to_node] = from_node
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.link_predecessor[to_node] = link.link_seq_no
+                G.link_preds[to_node] = link.link_seq_no
                 if status[to_node] != 1:
                     if status[to_node] == 2:
                         SEList.appendleft(to_node)
@@ -190,7 +195,7 @@ def _single_source_shortest_path_dijkstra(G, origin_node_no):
         if status[from_node] == 1:
             continue
         status[from_node] = 1
-        for link in G.node_list[from_node].outgoing_link_list:
+        for link in G.nodes[from_node].outgoing_links:
             to_node = link.to_node_seq_no
             new_to_node_cost = label_cost + link.cost
             # we only compare cost at the downstream node ToID
@@ -200,10 +205,10 @@ def _single_source_shortest_path_dijkstra(G, origin_node_no):
                 G.node_label_cost[to_node] = new_to_node_cost
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.node_predecessor[to_node] = from_node
+                G.node_preds[to_node] = from_node
                 # pointer to previous physical node index
                 # from the current label at current node and time
-                G.link_predecessor[to_node] = link.link_seq_no
+                G.link_preds[to_node] = link.link_seq_no
                 heapq.heappush(SEList, (G.node_label_cost[to_node], to_node))
 
 
@@ -222,13 +227,13 @@ def single_source_shortest_path(G, origin_node_id,
         # Initialization for all nodes
         G.node_label_cost = [MAX_LABEL_COST] * G.node_size
         # pointer to previous node index from the current label at current node
-        G.node_predecessor = [-1] * G.node_size
+        G.node_preds = [-1] * G.node_size
         # pointer to previous node index from the current label at current node
-        G.link_predecessor = [-1] * G.node_size
+        G.link_preds = [-1] * G.node_size
 
         # make sure node_label_cost, node_predecessor, and link_predecessor
         # are initialized even the source node has no outgoing links
-        if not G.node_list[origin_node_no].outgoing_link_list:
+        if not G.nodes[origin_node_no].outgoing_links:
             return
 
         if sp_algm.lower() == 'fifo':
@@ -239,7 +244,7 @@ def single_source_shortest_path(G, origin_node_id,
             _single_source_shortest_path_dijkstra(G, origin_node_no)
         else:
             raise Exception('Please choose correct shortest path algorithm: '
-                            +'fifo or deque or dijkstra')
+                            'fifo or deque or dijkstra')
 
 
 def output_path_sequence(G, to_node_id, type='node'):
@@ -248,52 +253,55 @@ def output_path_sequence(G, to_node_id, type='node'):
     Note that this function returns GENERATOR rather than list.
     """
     path = []
-    current_node_seq_no = G.node_id_to_no_dict[to_node_id]
+    current_node_seq_no = G.map_id_to_no[to_node_id]
 
     if type.startswith('node'):
         # retrieve the sequence backwards
         while current_node_seq_no >= 0:
             path.append(current_node_seq_no)
-            current_node_seq_no = G.node_predecessor[current_node_seq_no]
+            current_node_seq_no = G.node_preds[current_node_seq_no]
         # reverse the sequence
         for node_seq_no in reversed(path):
-            yield G.node_no_to_id_dict[node_seq_no]
+            yield G.map_no_to_id[node_seq_no]
     else:
         # retrieve the sequence backwards
-        current_link_seq_no = G.link_predecessor[current_node_seq_no]
+        current_link_seq_no = G.link_preds[current_node_seq_no]
         while current_link_seq_no >= 0:
             path.append(current_link_seq_no)
-            current_node_seq_no = G.node_predecessor[current_node_seq_no]
-            current_link_seq_no = G.link_predecessor[current_node_seq_no]
+            current_node_seq_no = G.node_preds[current_node_seq_no]
+            current_link_seq_no = G.link_preds[current_node_seq_no]
         # reverse the sequence
         for link_seq_no in reversed(path):
-            yield G.link_list[link_seq_no].get_link_id()
+            yield G.links[link_seq_no].get_link_id()
 
 
 def _get_path_cost(G, to_node_id):
-    to_node_no = G.node_id_to_no_dict[to_node_id]
+    to_node_no = G.map_id_to_no[to_node_id]
 
     return G.node_label_cost[to_node_no]
 
 
 def find_shortest_path(G, from_node_id, to_node_id, seq_type='node'):
-    if from_node_id not in G.node_id_to_no_dict.keys():
+    if from_node_id not in G.map_id_to_no.keys():
         raise Exception(f'Node ID: {from_node_id} not in the network')
-    if to_node_id not in G.node_id_to_no_dict.keys():
+    if to_node_id not in G.map_id_to_no.keys():
         raise Exception(f'Node ID: {to_node_id} not in the network')
 
     single_source_shortest_path(G, from_node_id, engine_type='c')
 
     path_cost = _get_path_cost(G, to_node_id)
 
-    if path_cost == MAX_LABEL_COST:
+    if path_cost >= MAX_LABEL_COST:
         return f'distance: infinity | path: '
 
     path = ';'.join(
         str(x) for x in output_path_sequence(G, to_node_id, seq_type)
     )
 
-    return f'distance: {path_cost:.2f} | path: {path}'
+    if seq_type.startswith('node'):
+        return f'distance: {path_cost:.2f} mi | node path: {path}'
+    else:
+        return f'distance: {path_cost:.2f} mi | link path: {path}'
 
 
 def find_path_for_agents(G, column_pool, engine_type='c'):
@@ -311,7 +319,7 @@ def find_path_for_agents(G, column_pool, engine_type='c'):
         G.setup_agents(column_pool)
 
     from_node_id_prev = -1
-    for agent in G.agent_list:
+    for agent in G.agents:
         from_node_id = agent.o_node_id
         to_node_id = agent.d_node_id
 
@@ -319,9 +327,9 @@ def find_path_for_agents(G, column_pool, engine_type='c'):
         if from_node_id == to_node_id:
             continue
 
-        if from_node_id not in G.node_id_to_no_dict.keys():
+        if from_node_id not in G.map_id_to_no.keys():
             raise Exception(f'Node ID: {from_node_id} not in the network')
-        if to_node_id not in G.node_id_to_no_dict.keys():
+        if to_node_id not in G.map_id_to_no.keys():
             raise Exception(f'Node ID: {to_node_id} not in the network')
 
         # simple caching strategy
@@ -334,17 +342,17 @@ def find_path_for_agents(G, column_pool, engine_type='c'):
         node_path = []
         link_path = []
 
-        current_node_seq_no = G.node_id_to_no_dict[to_node_id]
+        current_node_seq_no = G.map_id_to_no[to_node_id]
         # set up the cost
         agent.path_cost = G.node_label_cost[current_node_seq_no]
 
         # retrieve the sequence backwards
         while current_node_seq_no >= 0:
             node_path.append(current_node_seq_no)
-            current_link_seq_no = G.link_predecessor[current_node_seq_no]
+            current_link_seq_no = G.link_preds[current_node_seq_no]
             if current_link_seq_no >= 0:
                 link_path.append(current_link_seq_no)
-            current_node_seq_no = G.node_predecessor[current_node_seq_no]
+            current_node_seq_no = G.node_preds[current_node_seq_no]
 
         # make sure it is a valid path
         if not link_path:
